"""Este é o modulo "nester.py" (capitulo 1 do livro 'Head First Python').
Fornece uma função chamada print_lol() que imprime listas que podem ou não incluir outras listas aninhadas."""
def print_lol(the_list, nivel):
    """
    Esta função requer um argumento posicional chamado "The_list", que é qualquer lista Python (de possíveis listas aninhadas).
    Cada item de Dados na lista é (recursivamente) impresso na tela, cada um em sua linha.
    O segundo argumento (nivel) insere tabs de acordo com o nivel de aninhamento da lista.
    """
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, nivel+1)
        else:
            for tab_stop in range(nivel):
                print("\t", end='')
            print(each_item)



from distutils.core import setup

setup(
	name		= 'gilson_nester',
	version		= '1.1.0',
	py_modules	= ['gilson_nester'],
	author		= 'Gilson',
	author_email	= 'gilson10@gmail.com',
	url		= 'https://github.com/oliveiragil',
	description	= 'A simple printer for  nested lists - HF Python',
)
